@@ -20,7 +20,7 @@
 #include "drawsoundwidgetabstract.h"
 
 DrawSoundWidgetAbstract::DrawSoundWidgetAbstract(QWidget *parent, const char *name, SoundManager* sm)
-    : QCanvasView(parent,name,Qt::WNoAutoErase)
+ : QCanvasView(parent,name,WNoAutoErase)
 {
     soundManager=sm;
     canvas=new WaveCanvas(this->viewport());
@@ -33,8 +33,6 @@ DrawSoundWidgetAbstract::DrawSoundWidgetAbstract(QWidget *parent, const char *na
     updateCanvas=true;
     setVScrollBarMode(AlwaysOff);
     setHScrollBarMode(AlwaysOn);
-    oldVisibleSize=0;
-    canvas->setVisibleWidth(width());
 }
 
 
@@ -73,11 +71,11 @@ long DrawSoundWidgetAbstract::zoomToSamplePos(long start,long end)
     long diff=end-start;
     long mid=start+diff/2;
     //long temp_zoomRatio=long(float(diff)/float(((QCanvasView*)parent())->visibleWidth()));
-    long temp_zoomRatio=long(float(diff)/float(width()));
+    long temp_zoomRatio=long(float(diff)/float(parentWidget()->width()));
 std::cout<<"["<<name()<<"]: temp_zoom: "<<temp_zoomRatio<<" visibleWidth: "<<visibleWidth()<<" s-e:"<<start<<"-"<<end<<"\n";
     if(temp_zoomRatio<1) temp_zoomRatio=1;
-    setZoomRatio(temp_zoomRatio,FALSE);
-    center(mid/zoomRatio,canvas->height()/2);
+    setZoomRatio(temp_zoomRatio);
+    center(mid/zoomRatio,0);
     return zoomRatio;
 }
 
@@ -97,50 +95,40 @@ long DrawSoundWidgetAbstract::getFirstVisibleSample()
  */
 long DrawSoundWidgetAbstract::getLastVisibleSample()
 {
-    long v_Width=((QWidget*)parentWidget())->width();
+    long v_Width=parentWidget()->width();
     long end_sample=(contentsX()+v_Width)*getZoomRatio();
     return end_sample>soundManager->getFrames()?soundManager->getFrames():end_sample;
 }
 
 void DrawSoundWidgetAbstract::resizeEvent(QResizeEvent* ev){
+
     if(soundManager->hasSound() && ev->size().width()>20){
-        if(oldVisibleSize>0){
-            zoomRatio=round(oldVisibleSize/ev->size().width());
-            canvas->setZoomRatio(zoomRatio);
-            cout<<"in "<<name()<<" resizeEvent()"<<" zoomRatio: "<<zoomRatio<<"\n";
-            int scrollbarheight=horizontalScrollBar()->isHidden()?0:
-                    horizontalScrollBar()->height();
-            int c_height= height()-scrollbarheight;
-            canvas->resize(soundManager->getFrames()/zoomRatio,c_height);
-            canvas->setVisibleWidth(width());
-            canvas->setPixmapXOrigin(contentsX());
-            zapWaveCanvasBuffers();
-            zoomChanged();
-            resized();
-        }
-        oldVisibleSize=getLastVisibleSample()-getFirstVisibleSample();
+        long visibleSize=getLastVisibleSample()-getFirstVisibleSample();
+        zoomRatio=round(visibleSize/ev->size().width());
+        canvas->setZoomRatio(zoomRatio);
+        cout<<"in "<<name()<<" resizeEvent()"<<" zoomRatio: "<<zoomRatio<<"\n";
+        int scrollbarheight=horizontalScrollBar()->isHidden()?0:horizontalScrollBar()->height();
+        int c_height= ev->size().height()-scrollbarheight;
+        canvas->resize(soundManager->getFrames()/zoomRatio,c_height);
+        zapWaveCanvasBuffers();
+        zoomChanged();
+        resized();
     }
+
 }
 
 
 void DrawSoundWidgetAbstract::forceRepaint(){
     //called when applying LADSPA on whole wavefile
     //called after crop
-    //called when resizing window
-    if(soundManager->hasSound()){
-        //cout<<"in "<<name()<<" forceRepaint()\n";
-        canvas->setVisibleWidth(width());
-        canvas->forceRepaint();//0,soundManager->getFrames());
-    }
+    cout<<"in "<<name()<<" forceRepaint()\n";
+    canvas->forceRepaint(0,soundManager->getFrames());
 }
 
 void DrawSoundWidgetAbstract::forceRepaint(long start_sample,long end_sample){
-    if(soundManager->hasSound()){
-        assert(start_sample>=0 &&
-                end_sample<=soundManager->getFrames() && end_sample>start_sample);
-        //cout<<"in "<<name()<<" forceRepaint("<<start_sample<<","<<end_sample<<")\n";
-        canvas->forceRepaint(start_sample,end_sample);
-    }
+    assert(start_sample>=0 &&
+            end_sample<=soundManager->getFrames() && end_sample>start_sample);
+    canvas->forceRepaint(start_sample,end_sample);
 }
 
 
@@ -158,32 +146,29 @@ long DrawSoundWidgetAbstract::checkSamplePosition(long sample_pos)
          1) Changes zoom ratio
          2) Resizes the canvas,
 */
-void DrawSoundWidgetAbstract::setZoomRatio(long _zr,bool repaint){
+void DrawSoundWidgetAbstract::setZoomRatio(long _zr){
     cout<<"in "<<name()<<" setZoomRatio()\n";
-    zoomRatio=_zr!=0?_zr:1;
+    zoomRatio=_zr;
     canvas->setZoomRatio(zoomRatio);
     //on init
     int c_height=
             canvas->height()==0?sizeHint().height():canvas->height();
     //end on init
     canvas->resize(soundManager->getFrames()/zoomRatio,c_height);
-    canvas->setPixmapXOrigin(0);
-    zapWaveCanvasBuffers(repaint);
+    canvas->setPixmapXOrigin(contentsX());
+    zapWaveCanvasBuffers();
     zoomChanged();
     resized();
-
-    oldVisibleSize=getLastVisibleSample()-getFirstVisibleSample();
 }
 
 
 /*!
     \fn DrawSoundWidgetAbstract::zapWaveCanvasBuffers()
  */
-void DrawSoundWidgetAbstract::zapWaveCanvasBuffers(bool repaint)
+void DrawSoundWidgetAbstract::zapWaveCanvasBuffers()
 {
-    cout<<"in "<<name()<<" zapWaveCanvasBuffers()\n";
     canvas->zapBuffers();
-    if (repaint) forceRepaint();
+    forceRepaint();
 }
 
 
@@ -192,7 +177,6 @@ void DrawSoundWidgetAbstract::zapWaveCanvasBuffers(bool repaint)
  */
 void DrawSoundWidgetAbstract::zapWaveCanvasBuffers(long start, long end)
 {
-    cout<<"in "<<name()<<" zapWaveCanvasBuffers("<<start<<","<<end<<")\n";
     canvas->zapBuffers(start,end);
     forceRepaint(start,end);
 }
