@@ -30,8 +30,6 @@
 #include <qwidgetstack.h>
 #include <qvbox.h>
 #include <qpushbutton.h>
-#include <qhbuttongroup.h>
-#include "beatlinedata.h"
 /**
 @author Predrag Viceic
 */
@@ -45,9 +43,6 @@ public:
     void setApplyPolicy(int);
     void reinit();
     QSize sizeHint () const;
-    LADSPAEffect* getLadspa();
-    EffectPortFrame* getPortFrame(int portNo);
-    void updateDrawModeButton();
 
 private:
     LADSPAEffect* effect;
@@ -59,42 +54,30 @@ private:
     int applyMenuIDX;
     int undoApplyMenuIDX;
     QPopupMenu * executeMenu;
-    QPushButton* pointsButton;
     QPushButton* linesButton;
-    QPushButton* polylinesButton;
-    QPushButton* splinesButton;
-    QHButtonGroup* drawModeBG;
 
 
 public slots:
     void apply();
-    void apply(long,long);
+    void undoAndApply();
+    void undoAndApply(long,long);
     void show();
     void setZoomRatio(long);
     void visibleAreaChanged(long,long);
     void setContentsPos(int,int);
     void switchOnReleaseApplyPolicy();
     void switchOnChangeApplyPolicy();
-    void changeDrawMode(EffectPortFrame::DrawMode dm);
-    void lockedBeatLinesChanged(QValueList <beatline_data>);
-    void beatLinesChanged(QValueList <beatline_data>);
-    void setSplineData(int port_no, QValueList<SplinePoint>);
-    void setPolylineData(int port_no, QValueList<SortablePoint>);
-    void reinitLADSPAValues();
 
 
 signals:
     void applyMe(LADSPAEffect*);
-    void applyMe(LADSPAEffect*,long,long);
-    void lockedBeatLinesChangedS(QValueList <beatline_data>);
-    void beatLinesChangedS(QValueList <beatline_data>);
-    void zoomRatioChangedS(long _zr);
-    void applyPolicyChanged(int);
-    void cropS(long,long);
+    void undoAndApplyMe(LADSPAEffect*);
+    void undoAndApplyMe(LADSPAEffect*,long,long);
 
 
 protected:
     void closeEvent( QCloseEvent*);
+    bool wasEffectApplied;
 };
 
 #endif
