@@ -22,12 +22,8 @@
 
 #include <qhbox.h>
 #include <qvbox.h>
-#include <qpushbutton.h>
-#include <qvbuttongroup.h>
-#include "displayenvelopewidget.h"
-#include "envelope.h"
 #include "potentiometerwidget.h"
-
+#include "displayenvelopewidget.h"
 
 /**
 @author Predrag Viceic
@@ -39,32 +35,32 @@ public:
     EnvelopeControllerWidget(QWidget *parent = 0, const char *name = 0);
 
     ~EnvelopeControllerWidget();
+    double getEnvelopeValueAt(long x, long l_bound, long u_bound);
     void setInHolder(bool);
     long getEndFrame();
     long getStartFrame();
-    EnvelopeData* getEnvData();
 protected:
+    PotentiometerWidget* attackPotentiometer;
+    PotentiometerWidget* holdPotentiometer;
+    PotentiometerWidget* decayPotentiometer;
+    PotentiometerWidget* sustainPotentiometer;
+    PotentiometerWidget* releasePotentiometer;
+    PotentiometerWidget* attackQPotentiometer;
+    PotentiometerWidget* holdQPotentiometer;
+    PotentiometerWidget* decayQPotentiometer;
+    PotentiometerWidget* sustainQPotentiometer;
+    PotentiometerWidget* releaseQPotentiometer;
     DisplayEnvelopeWidget* displayEnvelope;
-    PotentiometerWidget* envDurationWidget;
-    PotentiometerWidget* envResolutionWidget;
-    EnvelopeData* envData;
-    QPushButton* onoff;
-    QButtonGroup* optionsBG;
-
     bool inHolder;
     long start_frame;
     long end_frame;
+    void mouseMoveEvent( QMouseEvent * );
 signals:
-    void envelopeChanged(EnvelopeData* envData);
+    void envelopeValueChanged();
 public slots:
     void setData(QString envData);
     void setEndFrame(long ef);
     void setStartFrame(long sf);
-    void durationChanged();
-    void resolutionChanged();
-    void endModeChanged(int btn);
-    void onoffChanged(bool on);
-    void envDataChanged();
 };
 
 #endif
