@@ -49,8 +49,6 @@
 #include "midimanager.h"
 #include "akpmanager.h"
 #include "sf2manager.h"
-#include "gigamanager.h"
-#include "dlsmanager.h"
 #include "mysavefiledialog.h"
 #include "myopenfiledialog.h"
 #include "spectrumview.h"
@@ -63,16 +61,7 @@
 #include "volumeslider.h"
 #include "mysplitter.h"
 #include "envelopecontrollerwidget.h"
-#include "replacedwaveholder.h"
-#include "projectmanager.h"
-#include "mysaveprojectdialog.h"
-#include "myloadprojectdialog.h"
-#include "midiinput.h"
-#include "midiinputthread.h"
-#include "midiconfigdialog.h"
-#include "sceneframe.h"
-#include "helpmanager.h" 
-
+#include "envelopeholder.h"
 
 class QTextEdit;
 
@@ -86,18 +75,13 @@ public:
 
 protected:
     void closeEvent( QCloseEvent* );
-public slots:
-    void load( const QString &fileName );
-    void loadProject(QString fn);
-    void configureMIDI();
-    void saveProject();
-    void help();
+
 private slots:
     void choose();
+    void load( const QString &fileName );
     void save();
     void saveAs();
     void saveChunks();
-    void saveProjectAs();
     void changeZoom(int value);
     void changeZoom();
     void changeTreshold(int value);
@@ -140,8 +124,6 @@ private slots:
     void numPad7Pressed();
     void numPad9Pressed();
     void numPad1Pressed();
-    void loadProject();
-    void saveLoopMidiFile();
 private:
     DrawSoundWidget* drawSoundWidget;
     DrawAllSoundWidget* drawAllSoundWidget;
@@ -162,9 +144,7 @@ private:
     MyOpenFileDialog* openFileDialog;
     MySaveFileDialog* saveFileDialog;
     EnvelopeControllerWidget* envelopeControllerWidget;
-    ReplacedWaveHolder* replacedWaveHolder;
-    SceneFrame* sceneFrame;
-    HelpManager* helpManager;
+    EnvelopeHolder* envelopeHolder;
 
 protected:
     QHBox* playButtons;
@@ -183,8 +163,7 @@ protected:
     QHBox* beatLinesControl;
     QHBox* envelopeControl;
     QHBox* playAndBeatLinesControls;
-    QPushButton* unlockBeatLinesButton;
-    QPushButton* lockBeatLinesButton;
+    QPushButton* clearBeatLinesButton;
     QSlider* analyseWindowDivider;
     QPushButton* bpmLines;
     QPushButton* viewOnly;
@@ -197,19 +176,7 @@ protected:
     EffectFrame* effectFrame;
     MidiManager* midiManager;
     AKPManager* akpManager;
-    SF2Manager* sf2Manager;
-    GigaManager* gigaManager;
-    DLSManager* dlsManager;
     MidiOutputThread* midiOutputThread;
-    QPopupMenu* filePopupMenu;
-    int idsavedialog, idsaveasdialog,idsavechunksdialog,
-        idsaveprojectasdialog, idsaveprojectdialog, idloadprojectdialog, idsaveloopmidifile;
-    ProjectManager* projectManager;
-    MySaveProjectDialog* saveProjectDialog;
-    MyLoadProjectDialog* loadProjectDialog;
-    MidiInput* midiInput;
-    MidiInputThread* midiInputThread;
-    MidiConfigDialog* midiConfigDialog;
 };
 
 
