@@ -41,8 +41,7 @@ void PotentiometerWidget::repaintScreen ( const QRect * _rect){
         pixmap.resize(rect().size());
         QPainter p(&pixmap);
         p.fillRect(rect(),colorGroup().background());
-        int image_num=maxValue()==minValue()?0:((value()-minValue())*99)/(maxValue()-minValue());
-        image_num=image_num<0?0:image_num>99?99:image_num;
+        int image_num= ((value()-minValue())*99)/(maxValue()-minValue());
         p.drawImage(rect(),getKnobImage(image_num).smoothScale(size()));
         bitBlt(this,0,0,&pixmap);
     }
